Functions for escaping and unescaping text in a RapidXML-compliant way.
Functions
- attribute_
value_ escape - Escapes the string so that it is a valid
"-quoted attribute value. - comment_
escape - Escapes the string so that it is valid inside a comment.
- content_
escape - Escapes the string so that it is valid as a text node.
- unescape
- Unescapes an XML escaped string. Keeps all unresolved entities unexpanded.