Module reader

Module reader 

An XML parser that tries to replicate RapidXML’s very incorrect parsing behaviour.

Prefixed names like mod:findName are implemented as an extension.

Parsing is done using default flags. Note that the behaviour of non-default flags can usually be reconstructed after parsing with default flags. That is unless the implementation of the flag is “buggy” in RapidXML itself, for example parse_pi_nodes and parse_declaration_node change behaviour on some invalid input.

Structs

AttributeEvent
An event returned by the Attributes iterator that represents a single attribute on a start tag.
Attributes
An iterator over the attributes of a StartEvent, obtained via StartEvent::attributes.
CDataEvent
An event emitted by cdata.
CommentEvent
An event emitted by comments.
DoctypeEvent
An event emitted by doctype declarations.
EndEvent
An event emitted by end tags like </hello>.
Error
A spanned XML parse error consisting of a span and an ErrorKind.
Options
XML reader options.
Reader
An XML reader.
StartEvent
An event emitted by start tags like <hello name="value"> or empty tags like <hello name="value"/>.
TextEvent
An event emitted by text content.

Enums

AttributeQuote
The quote character an attribute’s value can be wrapped in.
ErrorKind
An error that may be emitted by Reader while parsing XML.
Event
An event emitted by the Reader.