ErrorKind

Enum ErrorKind 

pub enum ErrorKind {
Show 16 variants TopLevelText, UnclosedPITag, ExpectedElementName, InvalidElementName, UnclosedElementTag, UnclosedEmptyElementTag, UnclosedEndTag, UnclosedElement, ExpectedAttributeEq, ExpectedAttributeValue, InvalidAttributeValue, UnclosedAttributeValue, UnclosedComment, UnclosedCData, UnclosedUnknownSpecial, DoctypeEof,
}
An error that may be emitted by Reader while parsing XML.

Variants



TopLevelText

Top-level text encountered while Options did not allow it.



UnclosedPITag

An unclosed processing instruction tag encountered.



ExpectedElementName

End of tag was encountered when an element name was expected.



InvalidElementName

An invalid character was encountered when an element name was expected.



UnclosedElementTag

An unclosed tag encountered.



UnclosedEmptyElementTag

An unclosed empty tag encountered.



UnclosedEndTag

An unclosed end tag encountered.



UnclosedElement

An unclosed element encountered while Options did not allow it.



ExpectedAttributeEq

Missing = character after attribute name.



ExpectedAttributeValue

Missing attribute value after = character.



InvalidAttributeValue

Attribute value contained a null byte.



UnclosedAttributeValue

An unclosed attribute value was encountered.



UnclosedComment

An unclosed comment was encountered.



UnclosedCData

An unclosed cdata was encountered.



UnclosedUnknownSpecial

An unclosed non-doctype “” tag encounteredd.



DoctypeEof

An unclosed doctype tag encountered.

Implementations

Source

impl ErrorKind

pub fn message(&self) -> &'static str

Returns an error message for this error kind.