StartEvent

Struct StartEvent 

pub struct StartEvent<'a> { /* private fields */ }
An event emitted by start tags like <hello name="value"> or empty tags like <hello name="value"/>.

Implementations

Source

impl<'a> StartEvent<'a>

pub fn prefix(&self) -> Option<&'a str>

Returns the prefix component of this event’s prefixed name, if present.

pub fn name(&self) -> &'a str

Returns the name component of this event’s prefixed name.

pub fn is_empty(&self) -> bool

Returns true if this event is an empty tag.

Notes

This method is not suitable for checking whether the content of this element is empty, it only checks whether the tag itself is of the self-closing variety.

pub fn position_in(&self, reader: &Reader<'_>) -> Range<usize>

Returns the span of this tag in reader.

Panics

May panic if reader is not the Reader that this event originated from.

pub fn name_position_in(&self, reader: &Reader<'_>) -> Range<usize>

Returns the span of this tag’s name component in reader.

Panics

May panic if reader is not the Reader that this event originated from.

pub fn prefix_position_in(&self, reader: &Reader<'_>) -> Option<Range<usize>>

Returns the span of this tag’s prefix component in reader.

Panics

May panic if reader is not the Reader that this event originated from.

pub fn prefixed_name_position_in(&self, reader: &Reader<'_>) -> Range<usize>

Returns the span of this tag’s prefixed name in reader.

Panics

May panic if reader is not the Reader that this event originated from.

pub fn attributes(&self) -> Attributes<'a>

Returns an iterator over the attribute events of this start tag.