Writer

Struct Writer 

pub struct Writer<W: Write> { /* private fields */ }
An XML writer.

Implementations

Source

impl<W: Write> Writer<W>

pub fn new(writer: W) -> Self

Creates a new Writer that will write into writer.

pub fn with_options(writer: W, options: Options) -> Self

Creates a new Writer that will write into writer with the specified options.

pub fn write_start( &mut self, prefix: Option<&str>, name: &str, ) -> Result<(), Error>

Writes a start tag with the specified prefix and name into the writer.

Errors

Returns an error if the prefix or name is invalid or an underlying I/O error occurs.

pub fn write_empty( &mut self, prefix: Option<&str>, name: &str, ) -> Result<(), Error>

Writes an empty tag with the specified prefix and name into the writer.

Errors

Returns an error if the prefix or name is invalid or an underlying I/O error occurs.

pub fn write_raw_attribute( &mut self, name: &str, quote: AttributeQuote, value: &str, ) -> Result<(), Error>

Writes an attribute with the specified prefix and name into the writer.

The attribute will use the double quote as the quote character. Does not escape the value but will return an error if is improperly escaped.

Must only be called in the context of a start tag, i.e. after a successful Self::write_start, Self::write_empty, Self::write_raw_attribute, or Self::write_attribute.

Errors

Returns an error if the name or value is invalid or an underlying I/O error occurs.

pub fn write_attribute(&mut self, name: &str, value: &str) -> Result<(), Error>

Writes an attribute with the specified prefix and name into the writer.

The attribute will use the double quote as the quote character.

Must only be called in the context of a start tag, i.e. after a successful Self::write_start, Self::write_empty, Self::write_raw_attribute, or Self::write_attribute.

Errors

Returns an error if the name is invalid or an underlying I/O error occurs.

pub fn write_end( &mut self, prefix: Option<&str>, name: &str, ) -> Result<(), Error>

Writes an end tag with the specified prefix and name into the writer.

Errors

Returns an error if the prefix or name is invalid or an underlying I/O error occurs.

pub fn write_raw_text(&mut self, text: &str) -> Result<(), Error>

Writes text content into the writer.

Errors

Returns an error if the content is improperly escaped or contains a null byte or an underlying I/O error occurs.

pub fn write_text(&mut self, content: &str) -> Result<(), Error>

Writes text content into the writer.

Notes

Currently this function does not check for null bytes in the string. This may change in a future release.

Errors

Returns an error if an underlying I/O error occurs.

pub fn write_cdata(&mut self, text: &str) -> Result<(), Error>

Writes cdata into the writer.

Notes

Currently this function does not check for null bytes in the string. This may change in a future release.

Errors

Returns an error if the string contains ]]> or an underlying I/O error occurs.

pub fn write_raw_comment(&mut self, text: &str) -> Result<(), Error>

Writes a comment into the writer.

Notes

Currently this function does not check for null bytes in the string. This may change in a future release.

Errors

Returns an error if the string contains --> or an underlying I/O error occurs.

pub fn write_comment(&mut self, content: &str) -> Result<(), Error>

Writes a comment into the writer.

Notes

Currently this function does not check for null bytes in the string. This may change in a future release.

Errors

Returns an error if an underlying I/O error occurs.

pub fn write_attribute_event( &mut self, attr: &AttributeEvent<'_>, ) -> Result<(), Error>

Writes a comment into the writer.

Notes

Currently this function does not check for null bytes in the string. This may change in a future release.

Errors

Returns an error if an underlying I/O error occurs.

pub fn write_event(&mut self, event: &Event<'_>) -> Result<(), Error>

Writes an event into the writer.

Errors

Returns an error if an underlying I/O error occurs.

pub fn inner_ref(&self) -> &W

Returns a reference to the underlying writer.

pub fn inner_mut(&mut self) -> &mut W

Returns a mutable reference to the underlying writer.

pub fn finish(self) -> Result<W>

If the writer is currently in a start tag context, ensures that the tag is closed, and then returns the underlying writer.

Errors

Returns an error if an underlying I/O error occurred.

pub fn flush(&mut self) -> Result<()>

If the writer is currently in a start tag context, ensures that the tag is closed, and then flushes the underlying writer.

Errors

Returns an error if an underlying I/O error occurred.