An XML parser that tries to replicate RapidXML’s very incorrect parsing behaviour.
Prefixed names like mod:findName are implemented as an extension.
Parsing is done using default flags.
Note that the behaviour of non-default flags can usually be reconstructed after parsing
with default flags.
That is unless the implementation of the flag is “buggy” in RapidXML itself, for example
parse_pi_nodes and parse_declaration_node change behaviour on some invalid input.
Structs
- Attribute
Event - An event returned by the
Attributesiterator that represents a single attribute on a start tag. - Attributes
- An iterator over the attributes of a
StartEvent, obtained viaStartEvent::attributes. - CData
Event - An event emitted by cdata.
- Comment
Event - An event emitted by comments.
- Doctype
Event - An event emitted by doctype declarations.
- EndEvent
- An event emitted by end tags like
</hello>. - Error
- A spanned XML parse error consisting of a span and an
ErrorKind. - Options
- XML reader options.
- Reader
- An XML reader.
- Start
Event - An event emitted by start tags like
<hello name="value">or empty tags like<hello name="value"/>. - Text
Event - An event emitted by text content.
Enums
- Attribute
Quote - The quote character an attribute’s value can be wrapped in.
- Error
Kind - An error that may be emitted by
Readerwhile parsing XML. - Event
- An event emitted by the
Reader.