pub struct StartEvent<'a> { /* private fields */ }Expand description
An event emitted by start tags like <hello name="value"> or empty tags like
<hello name="value"/>.
Implementations
Sourceimpl<'a> StartEvent<'a>
impl<'a> StartEvent<'a>
Sourcepub fn prefix(&self) -> Option<&'a str>
pub fn prefix(&self) -> Option<&'a str>
Returns the prefix component of this event’s prefixed name, if present.
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Returns true if this event is an empty tag.
Notes
This method is not suitable for checking whether the content of this element is empty, it only checks whether the tag itself is of the self-closing variety.
Sourcepub fn position_in(&self, reader: &Reader<'_>) -> Range<usize>
pub fn position_in(&self, reader: &Reader<'_>) -> Range<usize>
Sourcepub fn name_position_in(&self, reader: &Reader<'_>) -> Range<usize>
pub fn name_position_in(&self, reader: &Reader<'_>) -> Range<usize>
Sourcepub fn prefixed_name_position_in(&self, reader: &Reader<'_>) -> Range<usize>
pub fn prefixed_name_position_in(&self, reader: &Reader<'_>) -> Range<usize>
Sourcepub fn attributes(&self) -> Attributes<'a> ⓘ
pub fn attributes(&self) -> Attributes<'a> ⓘ
Returns an iterator over the attribute events of this start tag.